<div align="center">
  <img src="http://arelle.org/arelle/wp-content/themes/platform/images/logo-platform.png">
</div>

# Installation

The implementation is in Python 3.9, and is intended for Windows (any recent),
Mac OS-X 10.9+, Unix or Linux. The standard installation includes both desktop GUI,
a localhost RESTful web server and CLI.

The distributions include the Python and the resources needed to run Arelle.

You can download the distributions from the [Arelle website](https://arelle.org/arelle/pub/).

Arelle provides distributions for the following operating systems:
* Windows (x64 and x32 architecture)
* Mac OS
* Linux (Ubuntu)
* Red Hat
